#
# spec file for package uima-parent-pom
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           uima-parent-pom
Version:        18
Release:        1.1
Summary:        Apache UIMA Parent POM
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://uima.apache.org/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache:apache:pom:)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildArch:      noarch

%description
UIMA (Unstructured Information Management Architecture).
UIMA promotes community development and reuse of annotators
that extract meta-data from unstructured information (text,
audio, video, etc.); it provides for externalized declaration of
type systems, component configuration, aggregation, and more,
supports scalablity, and provides tooling.

This package provides Parent for Apache UIMA Projects.

%prep
%setup -q
# Unavailable deps
%pom_xpath_remove "pom:project/pom:profiles"

%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :maven-remote-resources-plugin
%pom_remove_plugin :maven-antrun-plugin
%pom_remove_plugin :maven-release-plugin

%build
%{mvn_build} -f

%install
%mvn_install

%files -f .mfiles
%doc README.md
%license LICENSE NOTICE

%changelog
* Mon Jun 23 2025 Fridrich Strba <fstrba@suse.com>
- Update to version 18
  * IssueConfigure rat plugin to print names of files with license
    issues to console during build - particularly useful when
    running in Jenkins
  * IssueRemoved workaround for resolved INFRA-14923
  * IssueRemove unused property
  * UIMA-6181: Fix complaints about maven-plugin-plugin in
    Eclipse
  * UIMA-6184: Move code quality profiles to parent POM
  * UIMA-6185: Upgrade parent POM plugins
  * UIMA-6254: Move API report post-analysis script into the build
    resources
  * UIMA-6293: Migrate UIMA Parent POM to GitHub
  * UIMA-6301: Rename "master" branches to "main"
  * UIMA-6307: Centralize Jenkins pipelines
  * UIMA-6316: Stop using the deprecated Pack200 when building
    update sites
  * UIMA-6320: Clean up parent POM
  * UIMA-6322: Clean up rat configuration
  * UIMA-6327: UIMA Parent POM 14 release
  * UIMA-6380: Maven plugin plugin from parent pom not compatible
    with Java 16
  * UIMA-6433: Update issue and PR templates
  * UIMA-6438: Add asf.yaml files to UIMA repos
  * UIMA-6439: Release build signs some 'sha512' files
  * UIMA-6441: Update plugins
  * UIMA-6456: UIMA Parent POM 15 release
  * UIMA-6458: Spurious "parsedVersion.osgiVersion" in file names
    in target
  * UIMA-6460: Move tycho and auto-staging to parent pom
  * UIMA-6463: Use toolchains to ensure compatibility with Java 1.8
  * UIMA-6467: Cannot build on Java 11
  * UIMA-6481: Enable issue management in GitHub repos
  * Added issue template for release issue
  * Remove Jira mention from PR template - we no longer use Jira.
  * Issue #26: Profile for OSGI bundles
  * Issue #28: Upgrade plugins
  * Issue #31: Switch changes report from Jira to GitHub
  * Issue #37: RC auto staging checks out SVN even on non-release
    builds
  * Issue #39: Upgrade plugins
  * Issue #42: Website on Maven Central search UI not shown properly
  * Issue #44: Remove deprecated profiles
  * Issue #48: Antrun executions for gpg should be skipped as well
    when skipping GPG is requested
  * Issue #50: Remove outdated website distribution config
  * Issue #53: Add profile for performing dependency checks
  * Issue #55: Remove the DocBook toolchain
  * Issue #57: Execute rat by default
  * Issue #59: Replace maven-changes-plugin with call to GH API to
    generate release notes
  * Issue #60: UIMA Parent POM 17
  * Issue #64: Update plugins and dependencies
  * Issue #66: Add support for unofficial JavaDoc tags
* Fri May 17 2024 Fridrich Strba <fstrba@suse.com>
- Update to version 13
  * UIMA-5612: first batch of upgrades to apache-wide parent pom
  * UIMA-5612: set versions for enforcer using properties
  * UIMA-5612: updates:
    1) fix jira version for reporting
    2) set property surefire.version to 2.20.1 (current level)
    3) make javadoc version use the variable
  * UIMA-5612: update the build for signed eclipse update site
  * UIMA-5856: Use modern checksum algorithms during release
  * UIMA-5876, UIMA-5753: updates for signatures/checksums and
    Java 11 enablement, details in the Jira comments. Includes
    patched jars and patches for two maven plugins
  * UIMA-5876: update uima-wide parent pom
  * UIMA-5897: workaround for Apache Nexus rule not allowing
    unsigned .sha512 checksums
  * UIMA-6059: apache license header can't be switched because
    it breaks rat check
  * UIMA-6059: http to https
- Fetch sources using service in order to filter out spurious
  binary files
- Remove bogus dependencies
* Fri Feb 28 2020 Fridrich Strba <fstrba@suse.com>
- Initial packaging of uima-parent-pom 10
